organizationinvitation

package
v2.5.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 5, 2026 License: MIT Imports: 5 Imported by: 1

Documentation

Overview

Code generated by "gen"; DO NOT EDIT. This file is meant to be re-generated in place and/or deleted at any time.

Package organizationinvitation provides the Organization Invitations API.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Create

Create creates and sends an invitation to join an organization.

func Get added in v2.0.9

Get retrieves the detail for an organization invitation.

func List added in v2.0.9

List returns a list of organization invitations

func ListFromInstance added in v2.1.0

ListAllFromInstance lists all the organization invitations from the current instance

func Revoke added in v2.0.9

Revoke marks the organization invitation as revoked.

Types

type Client

type Client struct {
	Backend clerk.Backend
}

Client is used to invoke the Organization Invitations API.

func NewClient

func NewClient(config *clerk.ClientConfig) *Client

func (*Client) Create

func (c *Client) Create(ctx context.Context, params *CreateParams) (*clerk.OrganizationInvitation, error)

Create creates and sends an invitation to join an organization.

func (*Client) Get added in v2.0.9

Get retrieves the detail for an organization invitation.

func (*Client) List added in v2.0.9

List returns a list of organization invitations

func (*Client) ListFromInstance added in v2.1.0

func (c *Client) ListFromInstance(ctx context.Context, params *ListFromInstanceParams) (*clerk.OrganizationInvitationList, error)

ListAllFromInstance lists all the organization invitations from the current instance

func (*Client) Revoke added in v2.0.9

func (c *Client) Revoke(ctx context.Context, params *RevokeParams) (*clerk.OrganizationInvitation, error)

Revoke marks the organization invitation as revoked.

type CreateParams

type CreateParams struct {
	clerk.APIParams
	EmailAddress    *string          `json:"email_address,omitempty"`
	Role            *string          `json:"role,omitempty"`
	RedirectURL     *string          `json:"redirect_url,omitempty"`
	InviterUserID   *string          `json:"inviter_user_id,omitempty"`
	PublicMetadata  *json.RawMessage `json:"public_metadata,omitempty"`
	PrivateMetadata *json.RawMessage `json:"private_metadata,omitempty"`
	OrganizationID  string           `json:"-"`
	ExpiresInDays   *int64           `json:"expires_in_days,omitempty"`
}

type GetParams added in v2.0.9

type GetParams struct {
	OrganizationID string
	ID             string
}

type ListFromInstanceParams added in v2.1.0

type ListFromInstanceParams struct {
	clerk.APIParams
	clerk.ListParams
	Statuses *[]string `json:"statuses,omitempty"`
	Query    *string   `json:"query,omitempty"`
	OrderBy  *string   `json:"order_by,omitempty"`
}

func (*ListFromInstanceParams) ToQuery added in v2.1.0

func (p *ListFromInstanceParams) ToQuery() url.Values

type ListParams added in v2.0.9

type ListParams struct {
	clerk.APIParams
	clerk.ListParams
	OrganizationID string
	Statuses       *[]string
	EmailAddress   *string
	OrderBy        *string
}

func (*ListParams) ToQuery added in v2.0.9

func (p *ListParams) ToQuery() url.Values

type RevokeParams added in v2.0.9

type RevokeParams struct {
	clerk.APIParams
	RequestingUserID *string `json:"requesting_user_id,omitempty"`
	OrganizationID   string  `json:"-"`
	ID               string  `json:"-"`
}

Jump to